summaryrefslogtreecommitdiffstats
path: root/src/bdd/cudd/cuddExport.c
diff options
context:
space:
mode:
authorAlan Mishchenko <alanmi@berkeley.edu>2009-02-15 08:01:00 -0800
committerAlan Mishchenko <alanmi@berkeley.edu>2009-02-15 08:01:00 -0800
commit0871bffae307e0553e0c5186336189e8b55cf6a6 (patch)
tree4571d1563fe33a53a57fea1c35fb668b9d33265f /src/bdd/cudd/cuddExport.c
parentf936cc0680c98ffe51b3a1716c996072d5dbf76c (diff)
downloadabc-0871bffae307e0553e0c5186336189e8b55cf6a6.tar.gz
abc-0871bffae307e0553e0c5186336189e8b55cf6a6.tar.bz2
abc-0871bffae307e0553e0c5186336189e8b55cf6a6.zip
Version abc90215
Diffstat (limited to 'src/bdd/cudd/cuddExport.c')
-rw-r--r--src/bdd/cudd/cuddExport.c24
1 files changed, 12 insertions, 12 deletions
diff --git a/src/bdd/cudd/cuddExport.c b/src/bdd/cudd/cuddExport.c
index d148be42..18caeaa0 100644
--- a/src/bdd/cudd/cuddExport.c
+++ b/src/bdd/cudd/cuddExport.c
@@ -119,7 +119,7 @@ Cudd_DumpBlif(
int i;
/* Build a bit array with the support of f. */
- sorted = ALLOC(int,nvars);
+ sorted = ABC_ALLOC(int,nvars);
if (sorted == NULL) {
dd->errorCode = CUDD_MEMORY_OUT;
goto failure;
@@ -136,7 +136,7 @@ Cudd_DumpBlif(
scan = cuddT(scan);
}
Cudd_RecursiveDeref(dd,support);
- support = NULL; /* so that we do not try to free it in case of failure */
+ support = NULL; /* so that we do not try to ABC_FREE it in case of failure */
/* Write the header (.model .inputs .outputs). */
if (mname == NULL) {
@@ -157,7 +157,7 @@ Cudd_DumpBlif(
if (retval == EOF) goto failure;
}
}
- FREE(sorted);
+ ABC_FREE(sorted);
sorted = NULL;
/* Write the .output line. */
@@ -184,7 +184,7 @@ Cudd_DumpBlif(
return(1);
failure:
- if (sorted != NULL) FREE(sorted);
+ if (sorted != NULL) ABC_FREE(sorted);
if (support != NULL) Cudd_RecursiveDeref(dd,support);
return(0);
@@ -325,7 +325,7 @@ Cudd_DumpDot(
long refAddr, diff, mask;
/* Build a bit array with the support of f. */
- sorted = ALLOC(int,nvars);
+ sorted = ABC_ALLOC(int,nvars);
if (sorted == NULL) {
dd->errorCode = CUDD_MEMORY_OUT;
goto failure;
@@ -342,7 +342,7 @@ Cudd_DumpDot(
scan = cuddT(scan);
}
Cudd_RecursiveDeref(dd,support);
- support = NULL; /* so that we do not try to free it in case of failure */
+ support = NULL; /* so that we do not try to ABC_FREE it in case of failure */
/* Initialize symbol table for visited nodes. */
visited = st_init_table(st_ptrcmp, st_ptrhash);
@@ -549,11 +549,11 @@ Cudd_DumpDot(
if (retval == EOF) goto failure;
st_free_table(visited);
- FREE(sorted);
+ ABC_FREE(sorted);
return(1);
failure:
- if (sorted != NULL) FREE(sorted);
+ if (sorted != NULL) ABC_FREE(sorted);
if (support != NULL) Cudd_RecursiveDeref(dd,support);
if (visited != NULL) st_free_table(visited);
return(0);
@@ -750,7 +750,7 @@ Cudd_DumpDDcal(
st_free_table(visited);
/* Build a bit array with the support of f. */
- sorted = ALLOC(int,nvars);
+ sorted = ABC_ALLOC(int,nvars);
if (sorted == NULL) {
dd->errorCode = CUDD_MEMORY_OUT;
goto failure;
@@ -767,7 +767,7 @@ Cudd_DumpDDcal(
scan = cuddT(scan);
}
Cudd_RecursiveDeref(dd,support);
- support = NULL; /* so that we do not try to free it in case of failure */
+ support = NULL; /* so that we do not try to ABC_FREE it in case of failure */
for (i = 0; i < nvars; i++) {
if (sorted[dd->invperm[i]]) {
if (inames == NULL || inames[dd->invperm[i]] == NULL) {
@@ -780,7 +780,7 @@ Cudd_DumpDDcal(
retval = fprintf(fp,"%s", i == nvars - 1 ? "\n" : " * ");
if (retval == EOF) goto failure;
}
- FREE(sorted);
+ ABC_FREE(sorted);
sorted = NULL;
/* Initialize symbol table for visited nodes. */
@@ -822,7 +822,7 @@ Cudd_DumpDDcal(
return(1);
failure:
- if (sorted != NULL) FREE(sorted);
+ if (sorted != NULL) ABC_FREE(sorted);
if (support != NULL) Cudd_RecursiveDeref(dd,support);
if (visited != NULL) st_free_table(visited);
return(0);